It has been reported that json_encode/decode() can be 14x faster than un/serialize().

Since Drupal uses that *a lot*, I wanted to know whether that is true.

CommentFileSizeAuthor
drupal.serialize.0.patch57.47 KBsun

Comments

sun’s picture

Version: 8.x-dev » 7.x-dev

Only for testing purposes.

sun’s picture

Version: 7.x-dev » 8.x-dev

ugh. Forget it. ;)

sun’s picture

Title: Serialize THIS, you tool! :) » Use json_encode/decode() instead of un/serialize()
Status: Needs review » Postponed
ogi’s picture

subscribe

damien tournoud’s picture

Status: Postponed » Closed (duplicate)